function [data,J] = dct2block(I,blksize,cnum,shift)
% DCT2BLOCK returns DCT coefficients of sliding windows
%   [DATA,J] = DCT2BLOCK(I,BLKSIZE,CNUM,SHIFT) extracts the first 1:CNUM
%   coefficients (in zigzag scan order) of 2D DCT transformed sliding 
%   BLKSIZExBLKSIZE windows. The windows are shifted forward by SHIFT pixel
%   in both horizontal and vertical direction
%
%   This is a utility function of EMMDB
%
%   Author: Roland Kwitt, rkwitt@gmx.at, 2009

    dim = size(I,3);
    szx = size(I,1);
    szy = size(I,2);
    Nx = 1:shift:szx-blksize+1;
    Ny = 1:shift:szy-blksize+1;
    for ch=1:dim % iterate over color bands
        cnt = 1;
        J{ch} = zeros(blksize,blksize,length(Nx)*length(Ny)); 
        C = I(:,:,ch);
        for i=Nx
            for j=Ny
                blk = C(i:i+blksize-1,j:j+blksize-1);
                J{ch}(:,:,cnt) = dct2(blk);
                cnt = cnt + 1;
            end
        end
    end
    Z = zigzag(blksize);
    data = []; 
    tmp = [];
    for z = cnum % number of coef. to extract
        
        % iterate over color channels and extract one coefficient so that
        % we achieve the interleaving YBRYBRYBR ...
        
        for ch = 1:dim 
            tmp = [J{ch}(Z(z,1),Z(z,2),:)];
            data = [data tmp(:)];
        end
    end
end