function em = emmembed(models,emNum)
% EMMEMBED constructs EMM models from higher-dimensional EMM models
%
%   EM = EMMEMBED(MODELs,EMNUM) returns the EMM models restricted to
%   dimensions 1:EMNUM from the EMMs given in MODELs
%
%   Example: given that models is cell with N EMM elements the following
%   call restricts the dimensions to the first 16 coefficients
%       em16 = emmembed(models,16);
%
%   Author: Roland Kwitt, 2009 (rkwitt at gmx dot at)

    for i=1:size(models,2)
        newSigma = models{i}.Sigma(:,1:emNum,:);
        [d1,d2,d3] = size(newSigma);
        for j=1:d3
            % check for entries which indicate non positive definiteness
            [maxi,indmaxi] = max(newSigma(:,:,j));
            [mini,indmini] = min(newSigma(:,:,j));
            [sorted,sortedidx] = sort(newSigma(:,:,j));
            for k=1:length(sorted)
                if (sorted(k) < maxi*eps)            
                    newSigma(:,sortedidx(k),j) = maxi*eps;
                end
            end
                    
            %if (mini < maxi*eps)
            %    fprintf('Found indication for non positive definiteness on index %d\n', indmini);
            %    newSigma(:,:,j)
            %    newSigma(:,indmini,j)
            %    s = sort(newSigma(:,:,j));
            %    s(1:10)
            %    mini
            %    pause
            %    newSigma(:,indmini,j) = maxi*eps;
            %end
        end

        em{i} = gmdistribution(models{i}.mu(:,1:emNum), ...
            newSigma, ...
            models{i}.PComponents);
    end
end
