% Script to generate test data equal to the data presented in the
% experimental section of the paper
%
% Vasconcelos, N. and Lippman, A., "Learning Mixture Hierarchies", In
% Proceddings of the International Conference on Neural Information
% Processing Systems (NIPS'98), Denver, Colorado, USA, 1998.
%
% Generate data from a Gaussian Mixture with 16 uniformly weighted
% components.

covariances = [...
    20 20; 
    21 21;
    21 20;
    15 15;
    17 17;
    18 20;
    20 18;
    15 15;
    16 20;
    20 16;
    19 14;
    19 19;
    13 19;
    19 16;
    18 13;
    18 15];

for i=1:16
    Sigma(1,:,i) = covariances(i,:);
end

mixp = ones(1,16)/16;
mu = [...
    -65 65;
    -65 85;
    -85 85;
    -85 65;
     65 65;
     85 85;
     65 85;
     85 65;
     65 -65;
     65 -85;
     85 -65;
     85 -85;
     -65 -65;
     -65 -85;
     -85 -65;
     -85 -85];

 
gm = gmdistribution(mu,Sigma,mixp);
% uncomment to plot the data
[X,Y] = meshgrid(-100:2:100,-100:2:100);
R = random(gm,1000);
Z = pdf(gm,[X(:) Y(:)]);
sz = size(X);
Z = reshape(Z,sz(1),sz(2));
mesh(X,Y,Z);
figure;
contour(X,Y,Z);

