function res  = rankemm(data,varargin)  
    p = inputParser;
    p.addRequired('data',@iscell);
    p.addParamValue('N', 1000, @(x)x>=100 && x <= 10000);
    p.addParamValue('debug',false,@islogical);
    p.addParamValue('method','mc', @(x)any(strcmpi(x,{'mc','vasc','gold'})));
    p.parse(data,varargin{:});
    N = p.Results.N;
    method = p.Results.method;
    debug = p.Results.debug;
    nimages = length(data);
    O = triu(ones(nimages,nimages));
    for i=1:nimages
        xi = data{i};
        if (debug)
            fprintf('processing query %d ',i);
            tic;
        end
        if (strcmp(method,'mc'))
            r = random(xi,N);
        end
        for j=1:nimages
            xj = data{j};
            switch method
                case 'mc'
                    if (O(i,j) == 1)
                        D(i,j) =  1/N * sum(log(pdf(xi,r))-log(pdf(xj,r)));
                    else
                        D(i,j) = D(j,i);
                    end
                case {'vasc','gold'}
                    D(i,j) = klapprox(xi,xj, ...
                        min(xi.NComponents,xj.NComponents), ...
                        min(xi.NDimensions,xj.NDimensions), ...
                        method);
            end
        end
        if (debug)
            tim = toc;
            fprintf('(%0.2f [s])\n',tim);
        end
    end
    res.distance = D;
    res.metric = method;
end
