function [r,ind] = vqlbg(d,k) 
%VQLBP implements the Linde-Buzo-Gray algorithm (LBP, aka generalized
%Lloyd) for the generation of a codebook. The algorithm is used together
%with the codeword splitting idea of Gray, R., "Vector Quantization", IEEE
%Signal Processing Magazine, Vol. 1, pages 4-29, April 1984
%   [R,IND] = VQLBG(D,K) computes R codebook vectors from the MxN matrix D
%   and further returns the codebook vector assignment in IND. Per
%   default, the pertuberation factor e which is also the termination
%   criteria is set to e=0.001;

e    = .001; 
r    = mean(d, 2); 
fprintf('dpr: %0.5f\n', 1/(size(d,1)*size(d,2)) * sum(disteu(d,r)));
%dpr = 10000;
Mk = size(d,1) * size(d,2);
dpr = 1/(size(d,1)*size(d,2)) * sum(disteu(d,r));
for i = 1:log2(k)
     r = [r*(1+e), r*(1-e)]; 
     while (true)
         % distance to the new cb vectors
         z = disteu(d, r);
         [m,ind] = min(z, [], 2);
         t = 0;
         for j = 1:2^i
              r(:, j) = mean(d(:, find(ind == j)), 2);
              x = disteu(d(:, find(ind == j)), r(:, j));
              for q = 1:length(x)
                   t = t + x(q); 
              end
         end
         t = t*1/Mk;
         fprintf('i: %d: (dpr-t)/t: %0.5f\t epsilon: %0.5f\n', i, (dpr-t)/t,e);
         if (((dpr - t)/t) < e) 
              break;
         else
              dpr = t;
         end
    end
end
